@@ -85,12 +85,12 @@ build_time_vars = {'ABIFLAGS': 'dm',
  'CONFINCLUDEDIR': '/usr/include',
  'CONFINCLUDEPY': '/usr/include/python3.7dm',
  'COREPYTHONPATH': '',
- 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.7.3/build/debug/coverage.info',
- 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.7.3/build/debug/lcov-report',
+ 'COVERAGE_INFO': '/builddir/build/BUILD/Python-3.7.4/build/debug/coverage.info',
+ 'COVERAGE_REPORT': '/builddir/build/BUILD/Python-3.7.4/build/debug/lcov-report',
  'COVERAGE_REPORT_OPTIONS': '--no-branch-coverage --title "CPython lcov '
                             'report"',
  'CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-             '-I/builddir/build/BUILD/Python-3.7.3/Include',
+             '-I/builddir/build/BUILD/Python-3.7.4/Include',
  'CXX': 'g++ -pthread',
  'DESTDIRS': '/usr /usr/lib64 /usr/lib64/python3.7 '
              '/usr/lib64/python3.7/lib-dynload',
@@ -579,7 +579,7 @@ build_time_vars = {'ABIFLAGS': 'dm',
  'MAINCC': 'gcc -pthread',
  'MAJOR_IN_MKDEV': 0,
  'MAJOR_IN_SYSMACROS': 1,
- 'MAKESETUP': '/builddir/build/BUILD/Python-3.7.3/Modules/makesetup',
+ 'MAKESETUP': '/builddir/build/BUILD/Python-3.7.4/Modules/makesetup',
  'MANDIR': '/usr/share/man',
  'MKDIR_P': '/usr/bin/mkdir -p',
  'MODBUILT_NAMES': 'posix  errno  pwd  _sre  _codecs  _weakref  _functools  '
@@ -676,7 +676,7 @@ build_time_vars = {'ABIFLAGS': 'dm',
                              '-Wno-cast-function-type '
                              '-Werror=implicit-function-declaration -IObjects '
                              '-IInclude -IPython -I. '
-                             '-I/builddir/build/BUILD/Python-3.7.3/Include '
+                             '-I/builddir/build/BUILD/Python-3.7.4/Include '
                              '-DPy_BUILD_CORE_BUILTIN',
  'PY_CFLAGS': '-Wno-unused-result -Wsign-compare '
               '-DDYNAMIC_ANNOTATIONS_ENABLED=1  -O2 -g -pipe -Wall '
@@ -724,7 +724,7 @@ build_time_vars = {'ABIFLAGS': 'dm',
                    '-Wno-unused-result -Wno-unused-parameter '
                    '-Wno-missing-field-initializers -Wno-cast-function-type '
                    '-Werror=implicit-function-declaration -IObjects -IInclude '
-                   '-IPython -I. -I/builddir/build/BUILD/Python-3.7.3/Include '
+                   '-IPython -I. -I/builddir/build/BUILD/Python-3.7.4/Include '
                    '-DPy_BUILD_CORE',
  'PY_CORE_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now  -g -Wl,-z,relro '
                     '-Wl,--as-needed  -Wl,-z,now '
@@ -732,7 +732,7 @@ build_time_vars = {'ABIFLAGS': 'dm',
                     '-fuse-linker-plugin -ffat-lto-objects '
                     '-flto-partition=none -g',
  'PY_CPPFLAGS': '-IObjects -IInclude -IPython -I. '
-                '-I/builddir/build/BUILD/Python-3.7.3/Include',
+                '-I/builddir/build/BUILD/Python-3.7.4/Include',
  'PY_FORMAT_SIZE_T': '"z"',
  'PY_LDFLAGS': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now  -g',
  'PY_LDFLAGS_NODIST': '-Wl,-z,relro -Wl,--as-needed  -Wl,-z,now '
@@ -766,7 +766,7 @@ build_time_vars = {'ABIFLAGS': 'dm',
                         '-Wno-cast-function-type '
                         '-Werror=implicit-function-declaration -IObjects '
                         '-IInclude -IPython -I. '
-                        '-I/builddir/build/BUILD/Python-3.7.3/Include',
+                        '-I/builddir/build/BUILD/Python-3.7.4/Include',
  'Py_DEBUG': 1,
  'Py_ENABLE_SHARED': 1,
  'Py_HASH_ALGORITHM': 0,
@@ -774,7 +774,7 @@ build_time_vars = {'ABIFLAGS': 'dm',
  'READELF': 'readelf',
  'RESSRCDIR': 'Mac/Resources/framework',
  'RETSIGTYPE': 'void',
- 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.7.3/build/debug',
+ 'RUNSHARED': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.7.4/build/debug',
  'SCRIPTDIR': '/usr/lib64',
  'SETPGRP_HAVE_ARG': 0,
  'SGI_ABI': '@SGI_ABI@',
@@ -802,8 +802,8 @@ build_time_vars = {'ABIFLAGS': 'dm',
  'SIZEOF_WCHAR_T': 4,
  'SIZEOF__BOOL': 1,
  'SOABI': 'cpython-37dm-aarch64-linux-gnu',
- 'SRCDIRS': 'Parser Objects Python Modules Programs',
- 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.7.3/Tools/gdb/libpython.py',
+ 'SRCDIRS': 'Parser Objects Python Modules Modules/_io Programs',
+ 'SRC_GDB_HOOKS': '/builddir/build/BUILD/Python-3.7.4/Tools/gdb/libpython.py',
  'STDC_HEADERS': 1,
  'STRICT_SYSV_CURSES': "/* Don't use ncurses extensions */",
  'STRIPFLAG': '-s',
@@ -816,10 +816,10 @@ build_time_vars = {'ABIFLAGS': 'dm',
  'TCLTK_LIBS': '',
  'TESTOPTS': '',
  'TESTPATH': '',
- 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.7.3/build/debug '
+ 'TESTPYTHON': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.7.4/build/debug '
                './python',
  'TESTPYTHONOPTS': '',
- 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.7.3/build/debug '
+ 'TESTRUNNER': 'LD_LIBRARY_PATH=/builddir/build/BUILD/Python-3.7.4/build/debug '
                './python /Tools/scripts/run_tests.py',
  'TESTTIMEOUT': 1200,
  'TIMEMODULE_LIB': 0,
@@ -828,10 +828,10 @@ build_time_vars = {'ABIFLAGS': 'dm',
  'UNICODE_DEPS': '\\',
  'UNIVERSALSDK': '',
  'UPDATE_FILE': 'python3.7 '
-                '/builddir/build/BUILD/Python-3.7.3/Tools/scripts/update_file.py',
+                '/builddir/build/BUILD/Python-3.7.4/Tools/scripts/update_file.py',
  'USE_COMPUTED_GOTOS': 1,
  'VERSION': '3.7',
- 'VPATH': '/builddir/build/BUILD/Python-3.7.3',
+ 'VPATH': '/builddir/build/BUILD/Python-3.7.4',
  'WINDOW_HAS_FLAGS': 1,
  'WITH_DOC_STRINGS': 1,
  'WITH_DTRACE': 1,
@@ -842,9 +842,9 @@ build_time_vars = {'ABIFLAGS': 'dm',
  'WITH_VALGRIND': 1,
  'X87_DOUBLE_ROUNDING': 0,
  'XMLLIBSUBDIRS': 'xml xml/dom xml/etree xml/parsers xml/sax',
- 'abs_builddir': '/builddir/build/BUILD/Python-3.7.3/build/debug',
- 'abs_srcdir': '/builddir/build/BUILD/Python-3.7.3',
+ 'abs_builddir': '/builddir/build/BUILD/Python-3.7.4/build/debug',
+ 'abs_srcdir': '/builddir/build/BUILD/Python-3.7.4',
  'datarootdir': '/usr/share',
  'exec_prefix': '/usr',
  'prefix': '/usr',
- 'srcdir': '/builddir/build/BUILD/Python-3.7.3'}
+ 'srcdir': '/builddir/build/BUILD/Python-3.7.4'}
